self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "95d6caaf61d6f55ff7b92f3857c427ec",
    "url": "/v1/admin/index.html"
  },
  {
    "revision": "87489b8314140b0f14ab",
    "url": "/v1/admin/static/css/2.190e409a.chunk.css"
  },
  {
    "revision": "87489b8314140b0f14ab",
    "url": "/v1/admin/static/js/2.ad51a3b2.chunk.js"
  },
  {
    "revision": "885409404f18b54d01cc",
    "url": "/v1/admin/static/js/main.8d66ae8b.chunk.js"
  },
  {
    "revision": "2d6f75dbe6d98c24968f",
    "url": "/v1/admin/static/js/runtime-main.bf4dcd2f.js"
  },
  {
    "revision": "448c34a56d699c29117adc64c43affeb",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.448c34a5.woff2"
  },
  {
    "revision": "89889688147bd7575d6327160d64e760",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.89889688.svg"
  },
  {
    "revision": "e18bbf611f2a2e43afc071aa2f4e1512",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.e18bbf61.ttf"
  },
  {
    "revision": "f4769f9bdb7466be65088239c12046d1",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.f4769f9b.eot"
  },
  {
    "revision": "fa2772327f55d8198301fdb8bcfc8158",
    "url": "/v1/admin/static/media/glyphicons-halflings-regular.fa277232.woff"
  }
]);